@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package IPC::Open3::Callback;
-$IPC::Open3::Callback::VERSION = '1.17';
+$IPC::Open3::Callback::VERSION = '1.18';
 # ABSTRACT: An extension to IPC::Open3 that will feed out and err to callbacks instead of requiring the caller to handle them.
 # PODNAME: IPC::Open3::Callback
 
@@ -289,12 +289,15 @@ sub _write_to_callback {
 
     return if ( !defined($callback) );
 
+    my $pid = $self->get_pid();
     if ( !defined($buffer_ref) ) {
-        &{$callback}( $data, $self->get_pid() );
+        &{$callback}( $data, $pid );
         return;
     }
 
-    &{$callback}($_) foreach ( $self->_append_to_buffer( $buffer_ref, $data, $flush ) );
+    foreach my $line ( $self->_append_to_buffer( $buffer_ref, $data, $flush ) ) {
+        &{$callback}( $line, $pid );
+    }
 }
 
 1;
@@ -309,7 +312,7 @@ IPC::Open3::Callback - An extension to IPC::Open3 that will feed out and err to
 
 =head1 VERSION
 
-version 1.17
+version 1.18
 
 =head1 SYNOPSIS
 
